@@ -33,53 +33,49 @@ class RenogyChargeController(minimalmodbus.Instrument):
             registeraddress, number_of_decimals, functioncode, False
         )
 
-    @retry(wait_fixed=200, stop_max_attempt_number=5)
-    def retriable_read_float(
-        self, registeraddress, functioncode=3, number_of_registers=2, byteorder=0
-    ):
-        return self.read_float(
-            registeraddress, functioncode, number_of_registers, byteorder
-        )
-
     @retry(wait_fixed=200, stop_max_attempt_number=5)
     def retriable_read_bit(self, registeraddress, functioncode):
         return self.read_bit(registeraddress, functioncode)
 
     def get_solar_voltage(self):
         """PV array input in volts"""
-        return self.retriable_read_float(0x0107, 3, 2) * 10
+        return self.retriable_read_register(0x0107, 1, 3)
 
     def get_solar_current(self):
         """PV array input in amps"""
-        return self.retriable_read_float(0x0108, 3, 2) * 100
+        return self.retriable_read_register(0x0108, 2, 3)
 
     def get_solar_power(self):
         """PV array input in watts"""
-        return self.retriable_read_float(0x0109, 3, 2)
+        return self.retriable_read_register(0x0109, 0, 3)
 
     def get_load_voltage(self):
         """Load output in volts"""
-        return self.retriable_read_float(0x0104, 3, 2)  * 10
+        return self.retriable_read_register(0x0104, 1, 3)
 
     def get_load_current(self):
         """Load output in amps"""
-        return self.retriable_read_float(0x0105, 3, 2) * 100
+        return self.retriable_read_register(0x0105, 2, 3)
 
     def get_load_power(self):
         """Load output in watts"""
-        return self.retriable_read_float(0x0106, 3, 2)
+        return self.retriable_read_register(0x0106, 0, 3)
 
     def get_battery_voltage(self):
         """Battery voltage"""
-        return self.retriable_read_float(0x0101, 3, 2) * 10
+        return self.retriable_read_register(0x0101, 1, 3)
 
     def get_battery_state_of_charge(self):
         """Battery state of charge"""
-        return self.retriable_read_float(0x0100, 3, 2)
+        return self.retriable_read_register(0x0100, 0, 3)
 
     def get_battery_temperature(self):
         """battery temperature"""
-        raise NotImplementedError
+        register_value = self.read_register(0x0103, 0, 3) & 0x00ff & 0x0ff
+        battery_temperature = register_value & 0x00ff & 0x0ff
+        battery_temperature_sign = register_value & 0x00ff >> 7
+        battery_temperature = -battery_temperature if battery_temperature_sign == 0 else battery_temperature
+        return battery_temperature
 
     def get_remote_battery_temperature(self):
         """The battery temperature measured by remote temperature sensor"""
@@ -87,7 +83,11 @@ class RenogyChargeController(minimalmodbus.Instrument):
 
     def get_controller_temperature(self):
         """Temperature inside equipment"""
-        raise NotImplementedError
+        register_value = self.read_register(0x0103, 0, 3) >> 8
+        controller_temperature = register_value & 0x0ff
+        controller_temperature_sign = register_value >> 7
+        controller_temperature = -controller_temperature if controller_temperature_sign == 0 else controller_temperature
+        return controller_temperature
 
     def get_battery_status(self):
         """Battery status"""
